from setuptools import setup

setup(
    name='PyP6Xer',
    version='1.011.01',
    packages=['xerparser', 'xerparser.model', 'xerparser.model.classes'],
    url='',
    license='GNU GENERAL PUBLIC LICENSE',
    author='Hassan',
    author_email='hassan.emam@hotmail.com',
    description='Parser for XER written in Python'
)
